@@ -1,21 +1,17 @@
-from __future__ import division
-from __future__ import print_function
-from builtins import range
-from past.utils import old_div
-from builtins import object
-
 from transcriptic.util import humanize
 from transcriptic import dataset as get_dataset
 
 try:
-    import plotly.plotly as py
+    import plotly as py
     import pandas
     import matplotlib.pyplot as plt
     import plotly.tools as tls
     import numpy as np
 except ImportError:
-    raise ImportError("Please run `pip install transcriptic[analysis] if you "
-                      "would like to use the Transcriptic analysis module.")
+    raise ImportError(
+        "Please run `pip install transcriptic[analysis] if you "
+        "would like to use the Transcriptic analysis module."
+    )
 
 
 class _PlateRead(object):
@@ -29,32 +25,36 @@ class _PlateRead(object):
 
     """
 
-    def __init__(self, op_type, dataset, group_labels, group_wells=None,
-                 control_reading=None, name=None):
+    def __init__(
+        self,
+        op_type,
+        dataset,
+        group_labels,
+        group_wells=None,
+        control_reading=None,
+        name=None,
+    ):
         self.name = name
         self.dataset = dataset
         self.control_reading = control_reading
         self.op_type = op_type
         if self.op_type not in ["absorbance", "fluorescence", "luminescence"]:
-            raise RuntimeError(
-                "Data given is not from a spectrophotometry operation.")
-        if self.op_type != (self.dataset.attributes["instruction"]["operation"]
-                            ["op"]):
-            raise RuntimeError("Data given is not a %s operation." % op_type)
+            raise RuntimeError("Data given is not from a spectrophotometry operation.")
+        if self.op_type != (self.dataset.attributes["instruction"]["operation"]["op"]):
+            raise RuntimeError(f"Data given is not a {op_type} operation.")
 
         # Populate measurement params
         measure_params_dict = dict()
-        measure_params_dict["reader"] = self.dataset.attributes[
-            "warp"]["device_id"]
+        measure_params_dict["reader"] = self.dataset.attributes["warp"]["device_id"]
         dataset_op = self.dataset.attributes["instruction"]["operation"]
         if self.op_type == "absorbance":
-            measure_params_dict["wavelength"] = dataset_op["wavelength"].split(
-                ":")[0] + "nm"
+            measure_params_dict["wavelength"] = (
+                dataset_op["wavelength"].split(":")[0] + "nm"
+            )
         if self.op_type == "fluorescence":
             measure_params_dict["wavelength"] = (
-                "excitation: %s emission: %s" %
-                (dataset_op["excitation"].split(":")[0] + "nm",
-                 dataset_op["emission"].split(":")[0] + "nm")
+                f"excitation: {dataset_op['excitation'].split(':')[0] + 'nm'} "
+                f"emission: {dataset_op['emission'].split(':')[0] + 'nm'}"
             )
         if self.op_type == "luminescence":
             measure_params_dict["wavelength"] = ""
@@ -64,62 +64,49 @@ class _PlateRead(object):
         # Populate plate field
         plate_info_dict = dict()
         plate_info_dict["id"] = self.dataset.attributes["container"]["id"]
-        plate_info_dict["col_count"] = self.dataset.attributes[
-            "container"]["container_type"]["col_count"]
-        plate_info_dict["well_count"] = self.dataset.attributes[
-            "container"]["container_type"]["well_count"]
+        plate_info_dict["col_count"] = self.dataset.attributes["container"][
+            "container_type"
+        ]["col_count"]
+        plate_info_dict["well_count"] = self.dataset.attributes["container"][
+            "container_type"
+        ]["well_count"]
         self.params["plate"] = plate_info_dict
 
         # Get dataset and parse into DataFrame
         data_dict = get_dataset(self.dataset.attributes["id"])
         self.df = pandas.DataFrame()
-        well_count = self.dataset.attributes[
-            "container"]["container_type"]["well_count"]
-        col_count = self.dataset.attributes[
-            "container"]["container_type"]["col_count"]
+        well_count = self.dataset.attributes["container"]["container_type"][
+            "well_count"
+        ]
+        col_count = self.dataset.attributes["container"]["container_type"]["col_count"]
         # If no group well list specified, default to including all well data
         # values in one group
         if not group_wells:
-            self.df = pandas.DataFrame([x[0]
-                                        for x in list(data_dict.values())],
-                                       columns=[group_labels[0]])
+            self.df = pandas.DataFrame(
+                [x[0] for x in list(data_dict.values())], columns=[group_labels[0]]
+            )
         # If given list of all int, assume one group with all wells in list
         elif all(isinstance(i, int) for i in group_wells):
             if len(group_wells) > len(data_dict):
-                raise ValueError(
-                    "Sum of group lengths exceeds total no. of wells.")
-            wells = [
-                humanize(_, well_count, col_count).lower()
-                for _ in group_wells
-            ]
+                raise ValueError("Sum of group lengths exceeds total no. of wells.")
+            wells = [humanize(_, well_count, col_count).lower() for _ in group_wells]
             if not all(_ in data_dict for _ in wells):
-                raise ValueError(
-                    "Not all wells {} are in dataset {}."
-                    "".format(wells, data_dict)
-                )
+                raise ValueError(f"Not all wells {wells} are in dataset {data_dict}.")
 
             self.df = pandas.DataFrame(
-                [data_dict[_][0] for _ in wells],
-                columns=[group_labels[0]]
+                [data_dict[_][0] for _ in wells], columns=[group_labels[0]]
             )
         elif all(isinstance(i, list) for i in group_wells):
-            if group_wells and (sum([len(i) for i in group_wells]) >
-                                len(data_dict)):
-                raise ValueError(
-                    "Sum of group lengths exceeds total no. of wells.")
+            if group_wells and (sum([len(i) for i in group_wells]) > len(data_dict)):
+                raise ValueError("Sum of group lengths exceeds total no. of wells.")
             for (idx, well_list) in enumerate(group_wells):
-                wells = [
-                    humanize(_, well_count, col_count).lower()
-                    for _ in well_list
-                ]
+                wells = [humanize(_, well_count, col_count).lower() for _ in well_list]
                 if not all(_ in data_dict for _ in wells):
                     raise ValueError(
-                        "Not all wells {} are in dataset {}."
-                        "".format(wells, data_dict)
+                        f"Not all wells {wells} are in dataset {data_dict}."
                     )
                 col = pandas.DataFrame(
-                    [data_dict[_][0] for _ in wells],
-                    columns=[group_labels[0]]
+                    [data_dict[_][0] for _ in wells], columns=[group_labels[0]]
                 )
                 # if group_well members are of different lengths,
                 # concat automatically pads resultant DataFrame with NaN
@@ -127,7 +114,8 @@ class _PlateRead(object):
         else:
             raise ValueError(
                 "Format Error: Group Well List should be a list of list of \
-                 wells in robot format")
+                 wells in robot format"
+            )
 
         # If control absorbance object specified, create df_abj variable by
         # subtracting control df from original
@@ -148,6 +136,8 @@ class _PlateRead(object):
         \**plot_kwargs : dict, optional
             Optional dictionary of specifications for your plot type of choice
         """
+        py.offline.init_notebook_mode()
+
         mpl_fig, ax = plt.subplots()
         nl = "\n" if mpl else "<br>"
         ax.set_ylabel(self.op_type + nl + self.params["wavelength"])
@@ -162,17 +152,15 @@ class _PlateRead(object):
                         "xaxis": {
                             "tickmode": "array",
                             "ticktext": labels,
-                            "tickvals": list(range(1, len(labels)+1)),
+                            "tickvals": list(range(1, len(labels) + 1)),
                             "tickangle": 0,
-                            "tickfont": {
-                                "size": 10
-                            },
+                            "tickfont": {"size": 10},
                         }
                     }
                 }
             pyfig = tls.mpl_to_plotly(mpl_fig)
             pyfig.update(plt_kwargs)
-            return py.iplot(pyfig)
+            return py.offline.iplot(pyfig)
 
 
 class Absorbance(_PlateRead):
@@ -199,10 +187,12 @@ class Absorbance(_PlateRead):
 
     """
 
-    def __init__(self, dataset, group_labels, group_wells=None,
-                 control_abs=None, name=None):
-        _PlateRead.__init__(self, "absorbance", dataset, group_labels,
-                            group_wells, control_abs, name)
+    def __init__(
+        self, dataset, group_labels, group_wells=None, control_abs=None, name=None
+    ):
+        _PlateRead.__init__(
+            self, "absorbance", dataset, group_labels, group_wells, control_abs, name
+        )
 
     def beers_law(self, conc_list=None, use_adj=True, **kwargs):
         """"
@@ -223,7 +213,7 @@ class Absorbance(_PlateRead):
         """
         if "title" not in kwargs:
             if self.name:
-                kwargs["title"] = "Beer's Law (%s)" % self.name
+                kwargs["title"] = f"Beer's Law ({self.name})"
             else:
                 kwargs["title"] = "Beer's Law"
         if "yerr" not in kwargs:
@@ -241,22 +231,19 @@ class Absorbance(_PlateRead):
             dataf.mean().plot(**kwargs)
         else:
             plot_obj = pandas.DataFrame(
-                {"values": dataf.mean(), "conc": np.asarray(conc_list)})
-            result = np.polyfit(
-                plot_obj["conc"], plot_obj["values"], 1, full=True)
+                {"values": dataf.mean(), "conc": np.asarray(conc_list)}
+            )
+            result = np.polyfit(plot_obj["conc"], plot_obj["values"], 1, full=True)
             gradient, intercept = result[0]
             mpl_fig, ax = plt.subplots()
-            plot_obj.plot(
-                x="conc", y="values", kind="scatter", ax=ax, **kwargs)
-            plt.plot(
-                plot_obj["conc"], gradient*plot_obj["conc"] + intercept, '-')
+            plot_obj.plot(x="conc", y="values", kind="scatter", ax=ax, **kwargs)
+            plt.plot(plot_obj["conc"], gradient * plot_obj["conc"] + intercept, "-")
             ax.set_ylabel("Absorbance " + self.params["wavelength"])
 
             # Calculate R^2 from residuals
             ss_res = result[1]
-            ss_tot = np.sum(
-                np.square((plot_obj["values"] - plot_obj["values"].mean())))
-            print("%s R^2: %s" % (self.name, (1-old_div(ss_res, ss_tot))))
+            ss_tot = np.sum(np.square((plot_obj["values"] - plot_obj["values"].mean())))
+            print(f"{self.name} R^2: {1 - ss_res // ss_tot}")
 
 
 class Fluorescence(_PlateRead):
@@ -283,10 +270,18 @@ class Fluorescence(_PlateRead):
 
     """
 
-    def __init__(self, dataset, group_labels, group_wells=None,
-                 control_fluor=None, name=None):
-        _PlateRead.__init__(self, "fluorescence", dataset, group_labels,
-                            group_wells, control_fluor, name)
+    def __init__(
+        self, dataset, group_labels, group_wells=None, control_fluor=None, name=None
+    ):
+        _PlateRead.__init__(
+            self,
+            "fluorescence",
+            dataset,
+            group_labels,
+            group_wells,
+            control_fluor,
+            name,
+        )
 
 
 class Luminescence(_PlateRead):
@@ -313,10 +308,12 @@ class Luminescence(_PlateRead):
 
     """
 
-    def __init__(self, dataset, group_labels, group_wells=None,
-                 control_lumi=None, name=None):
-        _PlateRead.__init__(self, "luminescence", dataset, group_labels,
-                            group_wells, control_lumi, name)
+    def __init__(
+        self, dataset, group_labels, group_wells=None, control_lumi=None, name=None
+    ):
+        _PlateRead.__init__(
+            self, "luminescence", dataset, group_labels, group_wells, control_lumi, name
+        )
 
 
 def compare_standards(pr_obj, std_pr_obj):
@@ -337,26 +334,29 @@ def compare_standards(pr_obj, std_pr_obj):
     # Compare against mean of standard absorbance
     # Check to ensure CVs are at least 2 apart
     for indx in range(len(pr_obj.cv)):
-        cv_ratio = old_div(pr_obj.cv.iloc[indx], std_pr_obj.cv.iloc[indx])
+        cv_ratio = pr_obj.cv.iloc[indx] // std_pr_obj.cv.iloc[indx]
         if cv_ratio < 2:
-            print("Warning for %s: Sample CV is only %s times that of Standard \
-                CV. RMSE may be inaccurate." % (
-                pr_obj.cv.index[indx], cv_ratio))
+            print(
+                f"Warning for {pr_obj.cv.index[indx]}: Sample CV is only "
+                f"{cv_ratio} times that of Standard CV. RMSE may be inaccurate."
+            )
     # RMSE (normalized wrt to standard mean)
-    RMSE = (np.sqrt(np.square(pr_obj.df - std_pr_obj.df.mean()).mean()) /
-            std_pr_obj.df.mean() * 100)
-    RMSE = pandas.DataFrame(
-        RMSE, columns=["RMSE % (normalized to standard mean)"])
+    RMSE = (
+        np.sqrt(np.square(pr_obj.df - std_pr_obj.df.mean()).mean())
+        / std_pr_obj.df.mean()
+        * 100
+    )
+    RMSE = pandas.DataFrame(RMSE, columns=["RMSE % (normalized to standard mean)"])
 
-    sampleVariance = pandas.DataFrame(
-        pr_obj.df.var(), columns=["Sample Variance"])
+    sampleVariance = pandas.DataFrame(pr_obj.df.var(), columns=["Sample Variance"])
     sampleCV = pandas.DataFrame(pr_obj.cv, columns=["Sample (%) CV"])
 
     try:
         # pylint: disable=import-error
         from IPython.display import HTML, display
+
         if pr_obj.name:
-            display(HTML("<b>Standards Comparison (%s)</b>" % pr_obj.name))
+            display(HTML(f"<b>Standards Comparison ({pr_obj.name})</b>"))
         display(sampleVariance)
         display(sampleCV)
         display(RMSE)
